@@ -11,7 +11,7 @@
 #' @param y numeric vector with outputs / scores. If provided then it shall have the same size as \code{data}
 #' @param weights numeric vector with sampling weights. By default it's \code{NULL}. If provided then it shall have the same length as \code{data}
 #' @param predict_function function that takes two arguments: model and new data and returns numeric vector with predictions.   By default it is \code{yhat}.
-#' @param residual_function function that takes four arguments: model, data, response vector y and predict function (optionally). It should return a numeric vector with model residuals for given data. If not provided, response residuals (\eqn{y-\hat{y}}) are calculated. By default it is \code{residual_function_default}.
+#' @param residual_function function that takes four arguments: model, data, target vector y and predict function (optionally). It should return a numeric vector with model residuals for given data. If not provided, response residuals (\eqn{y-\hat{y}}) are calculated. By default it is \code{residual_function_default}.
 #' @param ... other parameters
 #' @param label character - the name of the model. By default it's extracted from the 'class' attribute of the model
 #' @param verbose logical. If TRUE (default) then diagnostic messages will be printed
@@ -58,20 +58,48 @@
 #' # silent execution
 #' aps_lm <- explain(aps_lm_model4, verbose = FALSE)
 #'
-#' # user provided predict_function
-#' aps_lm <- explain(aps_lm_model4, data = apartments, label = "model_4v", predict_function = predict)
-#'
 #' # set target variable
 #' aps_lm <- explain(aps_lm_model4, data = apartments, label = "model_4v", y = apartments$m2.price)
 #' aps_lm <- explain(aps_lm_model4, data = apartments, label = "model_4v", y = apartments$m2.price,
 #'                                    predict_function = predict)
+#'
+#' # user provided predict_function
+#' aps_ranger <- ranger::ranger(m2.price~., data = apartments, num.trees = 50)
+#' custom_predict <- function(X.model, newdata) {
+#'    predict(X.model, newdata)$predictions
+#' }
+#' aps_ranger_exp <- explain(aps_ranger, data = apartments, y = apartments$m2.price,
+#'                           predict_function = custom_predict)
+#'
+#'
+#' # user provided residual_function
+#' aps_ranger <- ranger::ranger(m2.price~., data = apartments, num.trees = 50)
+#' custom_residual <- function(X.model, newdata, y, predict_function) {
+#'    abs(y - predict_function(X.model, newdata))
+#' }
+#' aps_ranger_exp <- explain(aps_ranger, data = apartments,
+#'                           y = apartments$m2.price,
+#'                           residual_function = custom_residual)
+#'
+#' # binary classification
+#' titanic_ranger <- ranger::ranger(as.factor(survived)~., data = titanic_imputed, num.trees = 50,
+#'                                  probability = TRUE)
+#' # keep in mind that for binary classification y parameter has to be numeric  with 0 and 1 values
+#' titanic_ranger_exp <- explain(titanic_ranger, data = titanic_imputed, y = titanic_imputed$survived)
+#'
+#' # multilabel classification
+#' hr_ranger <- ranger::ranger(status~., data = HR, num.trees = 50, probability = TRUE)
+#' # keep in mind that for multilabel classification y parameter has to be a factor,
+#' # with same levels as in training data
+#' hr_ranger_exp <- explain(hr_ranger, data = HR, y = HR$status)
+#'
 #' # set model_info
 #' model_info <- list(package = "stats", ver = "3.6.2", type = "regression")
 #' aps_lm_model4 <- lm(m2.price ~., data = apartments)
 #' aps_lm_explainer4 <- explain(aps_lm_model4, data = apartments, label = "model_4v",
 #'                              model_info = model_info)
 #'
-#' \dontrun{
+#' \donttest{
 #' # set model_info
 #' model_info <- list(package = "stats", ver = "3.6.2", type = "regression")
 #' aps_lm_model4 <- lm(m2.price ~., data = apartments)
@@ -136,17 +164,17 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
   # as for issue #15, if data is in the tibble format then needs to be translated to data.frame
   if ("tbl" %in% class(data)) {
     data <- as.data.frame(data)
-    verbose_cat("  -> data              :  tibbble converted into a data.frame \n", verbose = verbose)
+    verbose_cat("  -> data              :  tibble converted into a data.frame \n", verbose = verbose)
   }
   # as was requested in issue #155, It works becasue if data is NULL, instruction will not be evaluated
   if ("matrix" %in% class(data) && is.null(rownames(data))) {
     rownames(data) <- 1:n
-    verbose_cat("  -> data              :  rownames to matrix was added ( from 1 to", n, ") \n", verbose = verbose)
+    verbose_cat("  -> data              :  rownames to data was added ( from 1 to", n, ") \n", verbose = verbose)
   }
   # issue #181 the same as above but for columns
-  if ("matrix" %in% class(data) && is.null(colnames(data))) {
+  if (any(c("matrix", "data.frame", "tbl") %in% class(data)) && is.null(colnames(data))) {
     colnames(data) <- 1:ncol(data)
-    verbose_cat("  -> data              :  colnames to matrix was added ( from 1 to", ncol(data), ") \n", verbose = verbose)
+    verbose_cat("  -> data              :  colnames to data was added ( from 1 to", ncol(data), ") \n", verbose = verbose)
   }
 
   # REPORT: checks for y present while data is NULL
@@ -166,12 +194,6 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
     if (length(y) != n) {
       verbose_cat("  -> target variable   :  length of 'y' is different than number of rows in 'data' (",color_codes$red_start,"WARNING",color_codes$red_end,") \n", verbose = verbose)
     }
-    if ((is.factor(y) | is.character(y))) {
-      verbose_cat("  -> target variable   :  Please note that 'y' is a factor.  (",color_codes$red_start,"WARNING",color_codes$red_end,")\n", verbose = verbose)
-      verbose_cat("  -> target variable   :  Consider changing the 'y' to a logical or numerical vector.\n", verbose = verbose)
-      verbose_cat("  -> target variable   :  Otherwise I will not be able to calculate residuals or loss function.\n", verbose = verbose)
-    }
-
 ### check removed due to https://github.com/ModelOriented/DALEX/issues/164
 #    if (!is.null(data)) {
 #      if (is_y_in_data(data, y)) {
@@ -231,7 +253,7 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
       if ((is.factor(y_hat) | is.character(y_hat))) {
         verbose_cat("  -> predicted values  :  factor (",color_codes$red_start,"WARNING",color_codes$red_end,") with levels: ", paste(unique(y_hat), collapse = ", "), "\n", verbose = verbose)
       } else if (!is.null(dim(y_hat))) {
-        verbose_cat("  -> predicted values  :  predict function returns multiple columns: ", ncol(y_hat), " (",color_codes$red_start,"WARNING",color_codes$red_end,") some of functionalities may not work \n", verbose = verbose)
+        verbose_cat("  -> predicted values  :  predict function returns multiple columns: ", ncol(y_hat), " (",color_codes$yellow_start,"default",color_codes$yellow_end,") \n", verbose = verbose)
       } else {
         verbose_cat("  -> predicted values  :  numerical, min = ", min(y_hat), ", mean = ", mean(y_hat), ", max = ", max(y_hat), " \n", verbose = verbose)
       }
@@ -252,6 +274,24 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
     verbose_cat("  -> model_info        :  type set to ", type, "\n", verbose = verbose)
   }
 
+  if (!is.numeric(y) & model_info$type == "regression") {
+    verbose_cat("  -> model_info        :  Model info detected regression task but 'y' is a", class(y), ".  (",color_codes$red_start,"WARNING",color_codes$red_end,")\n", verbose = verbose)
+    verbose_cat("  -> model_info        :  By deafult regressions tasks supports only numercical 'y' parameter. \n", verbose = verbose)
+    verbose_cat("  -> model_info        :  Consider changing to numerical vector.\n", verbose = verbose)
+    verbose_cat("  -> model_info        :  Otherwise I will not be able to calculate residuals or loss function.\n", verbose = verbose)
+  } else if (!is.numeric(y) & model_info$type == "classification") {
+    verbose_cat("  -> model_info        :  Model info detected classification task but 'y' is a", class(y), ".  (",color_codes$red_start,"WARNING",color_codes$red_end,")\n", verbose = verbose)
+    verbose_cat("  -> model_info        :  By deafult classification tasks supports only numercical 'y' parameter. \n", verbose = verbose)
+    verbose_cat("  -> model_info        :  Consider changing to numerical vector with 0 and 1 values.\n", verbose = verbose)
+    verbose_cat("  -> model_info        :  Otherwise I will not be able to calculate residuals or loss function.\n", verbose = verbose)
+  } else if (!is.factor(y) & model_info$type == "multiclass") {
+    verbose_cat("  -> model_info        :  Model info detected multiclass task but 'y' is a", class(y), ".  (",color_codes$red_start,"WARNING",color_codes$red_end,")\n", verbose = verbose)
+    verbose_cat("  -> model_info        :  By deafult classification tasks supports only factor 'y' parameter. \n", verbose = verbose)
+    verbose_cat("  -> model_info        :  Consider changing to a factor vector with true class names.\n", verbose = verbose)
+    verbose_cat("  -> model_info        :  Otherwise I will not be able to calculate residuals or loss function.\n", verbose = verbose)
+  }
+
+
   # REPORT: checks for residual_function
   if (is.null(residual_function)) {
     # residual_function not specified
