@@ -9,36 +9,56 @@
 #' @param cutoff a cutoff for classification models, needed for measures like recall, precision, ACC, F1. By default 0.5.
 #'
 #' @return An object of the class \code{model_performance}.
+#'
+#' It's a list with following fields:
+#'
+#' \itemize{
+#' \item \code{residuals} - data frame that contains residuals for each observation
+#' \item \code{measures} - list with calculated measures that are dedicated for the task, whether it is regression, binary classification or multiclass classification.
+#' \item \code{type} - character that specifies type of the task.
+#' }
+#'
 #' @references Explanatory Model Analysis. Explore, Explain and Examine Predictive Models. \url{https://pbiecek.github.io/ema/}
 #' @importFrom stats median weighted.mean
 #' @export
 #' @examples
-#'  \dontrun{
+#' \donttest{
+#' # regression
+#'
 #' library("ranger")
-#' titanic_ranger_model <- ranger(survived~., data = titanic_imputed, num.trees = 100,
-#'                                probability = TRUE)
-#' # It's a good practice to pass data without target variable
-#' explainer_ranger  <- explain(titanic_ranger_model, data = titanic_imputed[,-8],
-#'                              y = titanic_imputed$survived)
-#' # resulting dataframe has predicted values and residuals
-#' mp_ex_rn <- model_performance(explainer_ranger)
+#' apartments_ranger_model <- ranger(m2.price~., data = apartments, num.trees = 50)
+#' explainer_ranger_apartments  <- explain(apartments_ranger_model, data = apartments[,-1],
+#'                              y = apartments$m2.price, label = "Ranger Apartments")
+#' model_performance_ranger_aps <- model_performance(explainer_ranger_apartments )
+#' model_performance_ranger_aps
+#' plot(model_performance_ranger_aps)
+#' plot(model_performance_ranger_aps, geom = "boxplot")
+#' plot(model_performance_ranger_aps, geom = "histogram")
+#'
+#' # binary classification
 #'
 #' titanic_glm_model <- glm(survived~., data = titanic_imputed, family = "binomial")
-#' explainer_glm <- explain(titanic_glm_model, data = titanic_imputed[,-8],
-#'                          y = titanic_imputed$survived,
-#'                     predict_function = function(m,x) predict.glm(m,x,type = "response"),
-#'                          label = "glm")
-#' mp_ex_glm <- model_performance(explainer_glm)
-#' mp_ex_glm
-#' plot(mp_ex_glm)
-#' plot(mp_ex_glm, mp_ex_rn)
+#' explainer_glm_titanic <- explain(titanic_glm_model, data = titanic_imputed[,-8],
+#'                          y = titanic_imputed$survived)
+#' model_performance_glm_titanic <- model_performance(explainer_glm_titanic)
+#' model_performance_glm_titanic
+#' plot(model_performance_glm_titanic)
+#' plot(model_performance_glm_titanic, geom = "boxplot")
+#' plot(model_performance_glm_titanic, geom = "histogram")
 #'
-#' titanic_lm_model <- lm(survived~., data = titanic_imputed)
-#' explainer_lm <- explain(titanic_lm_model, data = titanic_imputed[,-8], y = titanic_imputed$survived)
-#' mp_ex_lm <- model_performance(explainer_lm)
-#' plot(mp_ex_lm)
-#' plot(mp_ex_glm, mp_ex_rn, mp_ex_lm)
-#'  }
+#' # multilabel classification
+#'
+#' HR_ranger_model <- ranger(status~., data = HR, num.trees = 50,
+#'                                probability = TRUE)
+#' explainer_ranger_HR  <- explain(HR_ranger_model, data = HR[,-6],
+#'                              y = HR$status, label = "Ranger HR")
+#' model_performance_ranger_HR <- model_performance(explainer_ranger_HR)
+#' model_performance_ranger_HR
+#' plot(model_performance_ranger_HR)
+#' plot(model_performance_ranger_HR, geom = "boxplot")
+#' plot(model_performance_ranger_HR, geom = "histogram")
+#'
+#'}
 #'
 model_performance <- function(explainer, ..., cutoff = 0.5) {
   test_explainer(explainer, has_data = TRUE, has_y = TRUE, function_name = "model_performance")
@@ -83,7 +103,7 @@ model_performance <- function(explainer, ..., cutoff = 0.5) {
       accuracy  = model_performance_accuracy(tp, fp, tn, fn),
       auc       = model_performance_auc(predicted, observed)
     )
-  } else {
+  } else if (type == "multiclass") {
     measures <- list(
       micro_F1 = model_performance_micro_f1(predicted, observed),
       macro_F1 = model_performance_macro_f1(predicted, observed),
@@ -91,6 +111,8 @@ model_performance <- function(explainer, ..., cutoff = 0.5) {
       accuracy = model_performance_accuracy_multi(predicted, observed),
       w_macro_auc = model_performance_weighted_macro_auc(predicted, observed)
     )
+  } else {
+    stop("`explainer$model_info$type` should be one of ['regression', 'classification', 'multiclass'] - pass `model_info = list(type = $type$)` to the `explain` function. Submit an issue on https://github.com/ModelOriented/DALEX/issues if you think that this model should be covered by default.")
   }
 
   residuals$label <- explainer$label
