@@ -22,5 +22,5 @@
 #' @export
 plot.model_parts <- function(x, ...) {
   class(x) <- class(x)[-1]
-  plot(x)
+  plot(x, ...)
 }
